@@ -1,4 +1,7 @@
 from copy import copy
+from typing import List
+
+from mlc_tools.core.class_ import Class
 
 
 class SerializeFormat(object):
@@ -18,7 +21,7 @@ class Model(object):
     def __init__(self):
         self.parser = None
 
-        self.classes = []
+        self.classes:List[Class] = []
         self.classes_for_data = []
         self.objects = []
         self.functions = []
@@ -49,7 +52,7 @@ class Model(object):
         self.auto_registration = True
         self.generate_ref_counter = False
 
-        self.simple_types = ["int", "float", "bool", "string", 'int64_t', 'uint', 'uint64_t']
+        self.simple_types = ["int", "float", "bool", "string", 'int64_t', 'uint', 'uint64_t', 'double']
 
         self.out_dict = None
         self.files = []
@@ -99,3 +102,10 @@ class Model(object):
 
     def add_file(self, cls, local_path, content):
         self.files.append((cls, local_path, content))
+
+    def get_subclasses_of_class(self, cls_name: str) -> List[Class]:
+        result: List[Class] = []
+        for cls in self.classes:
+            if cls.superclasses and cls.superclasses[0] == cls_name:
+                result.append(cls)
+        return result
